@@ -232,8 +232,6 @@ static int daemon_check_mask(const char *spec, const char *ip)
    }
    PRINTF(DBG_AUTH, ("%s does NOT match %s/%d\n", tstring, mstring, bits));
    return DICT_NOMATCH;
-   
-   return 0;
 }
 
 static int daemon_check_range(const char *spec, const char *ip)
@@ -434,7 +432,7 @@ static void daemon_write( const char *buf, int len )
                       " retval = %d, errno = %d\n",
                       left, len, count, errno );
 #endif
-            daemon_terminate( 0, __FUNCTION__ );
+            daemon_terminate( 0, __func__ );
          }
       }
       left -= count;
@@ -482,7 +480,7 @@ static void daemon_printf( const char *format, ... )
    va_end( ap );
    if ((len = strlen( buf )) >= BUFFERSIZE) {
       log_info( ":E: buffer overflow: %d\n", len );
-      daemon_terminate( 0, __FUNCTION__ );
+      daemon_terminate( 0, __func__ );
    }
 
    pt = alloca(2*len + 10); /* +10 for the case when buf == "\n"*/
@@ -1265,6 +1263,20 @@ static void daemon_show_server (
    const dictDatabase  *db;
    double        uptime;
 
+   int headwords;
+
+   int index_size;
+   char index_size_uom;
+
+   int data_size;
+   char data_size_uom;
+   int data_length;
+   char data_length_uom;
+
+   int max_dbname_len;
+
+   lst_Position databasePosition = first_database_pos ();
+
    daemon_printf( "%d server information\n", CODE_SERVER_INFO );
    daemon_mime();
 
@@ -1290,23 +1302,24 @@ static void daemon_show_server (
    }
 
    if (!site_info_no_dblist && count_databases()) {
-      daemon_printf( "Database      Headwords         Index"
-		     "          Data  Uncompressed\n" );
+      daemon_printf( "Database      Headwords         Index          Data  Uncompressed\n" );
 
-      lst_Position databasePosition = first_database_pos ();
+      databasePosition = first_database_pos ();
 
-      while ((db = next_database (&databasePosition, "*"))) {
-	 int headwords       = db->index ? db->index->headwords : 0;
+      while (db = next_database (&databasePosition, "*"),
+	     db != NULL)
+      {
+	 headwords       = (db->index ? db->index->headwords : 0);
 
-	 int index_size      = 0;
-	 char index_size_uom = 'k';
+	 index_size      = 0;
+	 index_size_uom = 'k';
 
-	 int data_size       = 0;
-	 char data_size_uom  = 'k';
-	 int data_length     = 0;
-	 char data_length_uom= 'k';
+	 data_size       = 0;
+	 data_size_uom  = 'k';
+	 data_length     = 0;
+	 data_length_uom= 'k';
 
-	 int max_dbname_len = 0;
+	 max_dbname_len = 0;
 
 	 assert (!db -> invisible);
 
@@ -1412,7 +1425,7 @@ static void daemon_auth( const char *cmdline, int argc, const char **argv )
    snprintf( buf, buf_size, "%s%s", daemonStamp, secret );
 
    MD5Init(&ctx);
-   MD5Update(&ctx, buf, strlen(buf));
+   MD5Update(&ctx, (const unsigned char *) buf, strlen(buf));
    MD5Final(digest, &ctx);
 
    for (i = 0; i < 16; i++)
