@@ -18,7 +18,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  * 
- * $Id: sl.c,v 1.13 2004/11/17 12:39:54 cheusov Exp $
+ * $Id: sl.c,v 1.14 2007/12/29 13:16:10 cheusov Exp $
  *
  * \section{Skip List Routines}
  *
@@ -112,14 +112,14 @@ static void _sl_check( sl_List list )
    int       count = 0;
    _sl_Entry pt;
    
-   _sl_check_list( list, __FUNCTION__ );
+   _sl_check_list( list, __func__ );
    for (pt = l->head->forward[0]; pt; pt = pt->forward[0] ) {
       ++count;
       if (pt && pt->forward[0]
 	  && l->compare( l->key( pt->datum ),
 			 l->key( pt->forward[0]->datum ) ) >= 0) {
 	 _sl_dump( list );
-	 err_internal( __FUNCTION__,
+	 err_internal( __func__,
 		       "Datum 0x%p=%lu >= 0x%p=%lu\n",
 		       l->key( pt->datum ),
 		       (unsigned long)l->key( pt->datum ),
@@ -128,7 +128,7 @@ static void _sl_check( sl_List list )
       }
    }
    if (count != l->count) {
-      err_internal( __FUNCTION__,
+      err_internal( __func__,
 		    "Count should be %d instead of %d\n", count, l->count );
    }
 }
@@ -139,7 +139,7 @@ static _sl_Entry _sl_create_entry( int maxLevel, const void *datum )
    _sl_Entry e;
 
    if (maxLevel > _sl_MaxLevel)
-      err_internal( __FUNCTION__,
+      err_internal( __func__,
 		    "level %d > %d\n", maxLevel, _sl_MaxLevel );
 
    e = xmalloc( sizeof( struct _sl_Entry )
@@ -178,9 +178,9 @@ sl_List sl_create( int (*compare)( const void *key1, const void *key2 ),
    }
 
    if (!compare)
-      err_internal( __FUNCTION__, "compare fuction is NULL\n" );
+      err_internal( __func__, "compare fuction is NULL\n" );
    if (!key)
-      err_internal( __FUNCTION__, "key fuction is NULL\n" );
+      err_internal( __func__, "key fuction is NULL\n" );
 
    l          = mem_get_object( _sl_Memory );
 #if MAA_MAGIC
@@ -209,7 +209,7 @@ void sl_destroy( sl_List list )
    _sl_Entry e;
    _sl_Entry next;
 
-   _sl_check_list( list, __FUNCTION__ );
+   _sl_check_list( list, __func__ );
    for (e = l->head; e; e = next) {
       next = e->forward[0];
 #if MAA_MAGIC
@@ -293,14 +293,14 @@ void sl_insert( sl_List list, const void *datum )
    int              level = _sl_random_level();
    _sl_Entry        entry;
 
-   _sl_check_list( list, __FUNCTION__ );
+   _sl_check_list( list, __func__ );
    
    key = l->key( datum );
 
    pt = _sl_locate( l, key, update );
 
    if (pt && !l->compare( l->key( pt->datum ), key ))
-      err_internal( __FUNCTION__,
+      err_internal( __func__,
 		    "Datum \"%s\" is already in list\n", PRINT(l,datum) );
 
    if (level > l->level) {
@@ -330,7 +330,7 @@ void sl_delete( sl_List list, const void *datum )
    const void       *key;
    int              i;
 
-   _sl_check_list( list, __FUNCTION__ );
+   _sl_check_list( list, __func__ );
    
    key = l->key( datum );
 
@@ -338,7 +338,7 @@ void sl_delete( sl_List list, const void *datum )
 
    if (!pt || l->compare( l->key( pt->datum ), key )) {
       _sl_dump( list );
-      err_internal( __FUNCTION__,
+      err_internal( __func__,
 		    "Datum \"%s\" is not in list\n", PRINT(l,datum) );
    }
 
@@ -364,7 +364,7 @@ const void *sl_find( sl_List list, const void *key )
    _sl_Entry        update[_sl_MaxLevel + 1];
    _sl_Entry        pt;
 
-   _sl_check_list( list, __FUNCTION__ );
+   _sl_check_list( list, __func__ );
 
    pt = _sl_locate( l, key, update );
 
@@ -388,7 +388,7 @@ int sl_iterate( sl_List list, sl_Iterator f )
    
 
    if (!list) return 0;
-   _sl_check_list( list, __FUNCTION__ );
+   _sl_check_list( list, __func__ );
 
 				/* WARNING! This *ASSUMES* that the data to
                                    the right of the current point will
@@ -425,7 +425,7 @@ int sl_iterate_arg( sl_List list, sl_IteratorArg f, void *arg )
    
 
    if (!list) return 0;
-   _sl_check_list( list, __FUNCTION__ );
+   _sl_check_list( list, __func__ );
 
 				/* WARNING! This *ASSUMES* that the data to
                                    the right of the current point will
@@ -435,7 +435,7 @@ int sl_iterate_arg( sl_List list, sl_IteratorArg f, void *arg )
    count = l->count;
    copy = alloca( count * sizeof( void * ) );
    for (i = 0, pt = l->head->forward[0]; pt; i++, pt = pt->forward[0]) {
-      _sl_check_entry( pt, __FUNCTION__ );
+      _sl_check_entry( pt, __func__ );
       copy[i] = pt->datum;
    }
    for (i = 0; i < count; i++) {
@@ -456,7 +456,7 @@ void _sl_dump( sl_List list )
    _sl_Entry pt;
    int       count = 0;
 
-   _sl_check_list( list, __FUNCTION__ );
+   _sl_check_list( list, __func__ );
 
    printf( "Level = %d, count = %d\n", l->level, l->count );
    for (pt = l->head; pt; pt = pt->forward[0]) {
